# pydantic-logfire

## Please use the [logfire](https://pypi.org/project/logfire/) package instead.

_(This is a stub package to redirect to [logfire](https://pypi.org/project/logfire/), and shouldn't be installed directly.)_
